# README

## IRB Folder Structure

This folder was structured to support the programming and execution of the software that it contains. Not all folders have the typical IDR data request structure. However, the "*Concatenated Results*" folder is the one most similar to that familiar structure. Please refer to that folder for the most comprehensive summary of the data request.
